@@ -310,16 +310,15 @@ bool SetFileAttr(const wchar *Name,uint Attr)
 void CalcFileSum(File *SrcFile,uint *CRC32,byte *Blake2,uint Threads,int64 Size,uint Flags)
 {
   SaveFilePos SavePos(*SrcFile);
-#if !defined(SILENT) && !defined(_WIN_CE)
+#ifndef SILENT
   int64 FileLength=SrcFile->FileLength();
-  if ((Flags & (CALCFSUM_SHOWTEXT|CALCFSUM_SHOWALL))!=0)
-  {
-    mprintf(St(MCalcCRC));
-    mprintf(L"     ");
-  }
-
 #endif
 
+#ifndef GUI
+  if ((Flags & (CALCFSUM_SHOWTEXT|CALCFSUM_SHOWALL))!=0)
+#endif
+    uiMsg(UIEVENT_FILESUMSTART);
+
   if ((Flags & CALCFSUM_CURPOS)==0)
     SrcFile->Seek(0,SEEK_SET);
 
@@ -345,9 +344,11 @@ void CalcFileSum(File *SrcFile,uint *CRC32,byte *Blake2,uint Threads,int64 Size,
 
     if ((++BlockCount & 0xf)==0)
     {
-#if !defined(SILENT) && !defined(_WIN_CE)
+#ifndef SILENT
+#ifndef GUI
       if ((Flags & CALCFSUM_SHOWALL)!=0)
-        mprintf(L"\b\b\b\b%3d%%",ToPercent(BlockCount*int64(BufSize),FileLength));
+#endif
+        uiMsg(UIEVENT_FILESUMPROGRESS,ToPercent(BlockCount*int64(BufSize),FileLength));
 #endif
       Wait();
     }
@@ -360,10 +361,10 @@ void CalcFileSum(File *SrcFile,uint *CRC32,byte *Blake2,uint Threads,int64 Size,
     if (Size!=INT64NDF)
       Size-=ReadSize;
   }
-#ifndef SILENT
+#ifndef GUI
   if ((Flags & CALCFSUM_SHOWALL)!=0)
-    mprintf(L"\b\b\b\b    ");
 #endif
+    uiMsg(UIEVENT_FILESUMEND);
 
   if (CRC32!=NULL)
     *CRC32=HashCRC.GetCRC32();
@@ -419,7 +420,7 @@ bool DelFile(const wchar *Name)
 
 
 
-#if defined(_WIN_ALL) && !defined(_WIN_CE) && !defined(SFX_MODULE)
+#if defined(_WIN_ALL) && !defined(SFX_MODULE)
 bool SetFileCompression(const wchar *Name,bool State)
 {
   HANDLE hFile=CreateFile(Name,FILE_READ_DATA|FILE_WRITE_DATA,
