@@ -158,6 +158,11 @@
 #define SAVE_LINKS
 #endif
 
+#if defined(__linux) && !defined (_ANDROID) || defined(__FreeBSD__)
+#include <sys/time.h>
+#define USE_LUTIMES
+#endif
+
 #define ENABLE_ACCESS
 
 #define DefConfigName  L".rarrc"
